<?php
/**
 * Ejemplo para Ágora 3.0
 */

## Preparación del ejemplo.

# Primero, indicamos al intérprete PHP que muestre *todos* los errores.
  error_reporting (E_ALL);
# Definimos las rutas donde buscar módulos y plantillas, en lugar de usar las
# definidas por Ágora por defecto.
  define ('AG_DIR_VISTAS', __DIR__.'/');
  define ('AG_DIR_MODULOS', AG_DIR_VISTAS);
# Ahora se carga el archivo "agora.php".
  require 'agora.php';

# Función de ayuda para generar mensajes de error.
  function mensajeError (string $aMensaje): string
  {
    return "<p class=\"error\">[Error] - $aMensaje</p>";
  }

# A continuación, parte del ejemplo de uso de las huellas (o cookies).
#
# Se hace aquí ya que no se permite el envío ni modificación de cabeceras si
# ya se devolvió algún dato al cliente (aunque sea un único carácter).
  $ValorEjemplo = Agora::tomaHuella ('ValorEjemplo', true);
  if ($ValorEjemplo):
    $resultadoHuella = "<p>La huella <var>ValorEjemplo</var> contiene el valor \"<kbd>$ValorEjemplo</kbd>\".&nbsp; Recargue la página para ver cómo cambia el valor.</p>";
  else:
    $resultadoHuella = '<p>No existe la huella <var>ValorEjemplo</var>.&nbsp; Intentará crearse a continuación.&nbsp; Recargue la página para comprobar si funciona.</p>';
    $ValorEjemplo = 0; # Valor inicial.
  endif;
# Ahora creamos o modificamos la huella.
  try
  {
    Agora::PonHuella ('ValorEjemplo', $ValorEjemplo + 1, time () + 300);
  }
  catch (\Exception $error)
  {
    $resultadoHuella = mensajeError
      ('Hubo un error al establecer la huella: "' . $error->getMessage () . '"');
  }

## Documento.
?><!DOCTYPE html>
<html lang="es-es">
 <head>
  <meta charset="UTF-8" />
  <title>Ejemplo Ágora <?= AG_VERSION ?></title>
  <meta name="author" content="Guillermo Martínez (TCC Ñuño Martínez)" />
  <meta name="description" content="Ejemplo de uso de Ágora <?= AG_VERSION ?>" />
  <meta name="robots" content="noindex,nofollow" />
  <link rel="stylesheet" type="text/css" href="normalize.css" />
  <link rel="stylesheet" type="text/css" href="estilo.css" />
 </head>
 <body>
  <header>
   <h1>Ejemplo Ágora <?= AG_VERSION ?></h1>
   <p>Este documento es un ejemplo de uso de Ágora.&nbsp; Cada sección muestra un método o utilidad diferente.&nbsp; Este ejemplo <strong>no</strong> incluye todos los métodos definidos por Ágora.&nbsp; Lea la <cite>Documentación</cite> incluida en el paquete para una explicación detallada.</p>
   <nav><ul>
    <li><a href="#inicio">Inicio</a></li>
    <li><a href="#configuracion">Acceso a <var>$Config</var></a></li>
    <li><a href="#XSS">Filtro XSS</a></li>
    <li><a href="#formulario">Formularios</a></li>
    <li><a href="#huellas">Huellas (cookies)</a></li>
    <li><a href="#plantillas">Uso de plantillas</a></li>
    <li><a href="#modulos">Uso de módulos</a></li>
   </ul></nav>
  </header>

  <section id="inicio">
   <header><h2>Inicio</h2></header>
   <p>La carga y configuración de Ágora se ha realizado al cargar este archivo.&nbsp; Consulte el código fuente.</p>
   <p>Si hubo algún problema en la carga de Ágora, aparecerán uno o más mensajes de error a lo largo de este documento.&nbsp; Si no hay mensajes de error o de aviso, es que todo va bien.</p>
  </section>

  <section id="configuracion">
   <header><h2>Acceso a <var>$Config</var></h2></header>
   <p>Definimos un diccionario <var>$Config</var> con algunos valores.</p>
<?php
# Valores para esta sección del ejemplo.
# Evidentemente esto es una simplificación y un caso real no definiría $Config
# aquí.
  $config = array (
  # Observe que los nombres están en minúsculas.  Esto es lo recomendable.
    'valor1' => 'Este es un valor almacenado en el diccionario de configuración.',
    'valor3' => 'Otro valor diferente.',
  );

# Definimos una constante para marcar los valores que no existan.
  define ('NO_EXISTE', '<s>no existe</s>');
 ?>
    <p>Ahora usamos Ágora para obtener valores:</p>
    <table>
     <thead><tr><th>Nombre de variable</th><th>Valor devuelto</th></tr></thead>
     <tbody>
       <tr><td>Valor1</td><td><?= Agora::config ('Valor1', NO_EXISTE) ?></td></tr>
       <tr><td>Valor2</td><td><?= Agora::config ('Valor2', NO_EXISTE) ?></td></tr>
       <tr><td>Valor3</td><td><?= Agora::config ('valor3', NO_EXISTE) ?></td></tr>
     </tbody>
    </table>
  </section>

  <section id="XSS">
   <header><h2>Filtro XSS</h2></header>
   <p>Un ejemplo de uso del método <code>Agora::filtraXSS (...)</code> para evitar inyección de código JavaScript:</p>
<?php
# Contenemos el código JavaScript en una variable, para usar el mismo código siempre.
  $codigoJS = 'Tienes un ejemplo de código en el siguiente enlace: <a href="" onClick="window.alert (\'¡Hola, Mundo!\'); return false;">link</a>';
# Lo mostramos usando FiltroXSS.
  echo '<p>'.Agora::filtraXSS ($codigoJS).'</p>';
 ?>
   <p>A continuación no usamos el filtro (Nota: el navegador debe tener JavaScript activado para que funcione la inyección):</p>
<?php
# Lo mostramos sin usar filtraXSS.
  echo '<p>'.$codigoJS.'</p>';
 ?>
  </section>

  <section id="formulario">
   <header><h2>Formularios</h2></header>
   <p>Aquí se muestra cómo usar Ágora para comprobar y asegurar datos enviados por un formulario.&nbsp; Puede tratar de inyectar código HTML, PHP o JavaScript para ver qué sucede.</p>
<?php
# Comprobamos si se enviaron ya los datos.
  if (Agora::post ('nombre') and Agora::post ('apellidos')):
  # Se enviaron, así que mostramos los datos.
 ?>
   <h3>Datos recibidos</h3>
   <dl>
    <dt>Nombre:</dt><dd><?= Agora::post ('nombre', true) ?></dd>
    <dt>Apellidos:</dt><dd><?= Agora::post ('apellidos', true) ?></dd>
    <dt>Biografía:</dt><dd><?= Agora::post ('biografia', true) ?></dd>
   </dl>
<?php
  else:
  # ¿Olvidó algún dato?
    if (Agora::post ('nombre') or Agora::post ('apellidos')):
      $mensaje =
	mensajeError ('Debe indicar el nombre <b>y</b> los apellidos.');
    elseif (Agora::post ('biografia')):
      $mensaje =
	mensajeError ('Debe indicar el nombre <b>y</b> los apellidos.');
    else:
      $mensaje = '';
    endif;
 ?>
   <form action="#formulario" method="post">
   <?= $mensaje ?>
   <fieldset>
    <legend>Datos del usuario</legend>
    <p><label for="nombre">Nombre:</label>&nbsp;<input type="text" name="nombre" id="nombre" value="<?= Agora::post ('nombre', true) ?>" placeholder="Nombre" /></p>
    <p><label for="apellidos">Apellidos:</label>&nbsp;<input type="text" name="apellidos" id="apellidos" value="<?= Agora::post ('apellidos', true) ?>" placeholder="Apellidos" /></p>
    <p><label for="biografia">Biografía:</label></p>
    <p><textarea name="biografia" id="biografia" rows="15" cols="80" placeholder="Biografía"><?= Agora::post ('biografia', true) ?></textarea></p>
    <p><input type="submit" value="Enviar" /></p>
   </fieldset>
   </form>
<?php
  endif;
 ?>
  </section>

  <section id="huellas">
   <header><h2>Huellas (cookies)</h2></header>
   <p>En esta sección se muestra el uso de huellas (o <em lang="en">cookies</em>).&nbsp; Evidentemente, el navegador debe tener activado el soporte adecuado para su uso.</p>
<?php
# Nótese que el trabajo no se realiza aquí, sino al inicio del documento.
  echo $resultadoHuella;
 ?>
  </section>

  <section id="plantillas">
   <header><h2>Uso de plantillas</h2></header>
<?php
  try
  {
    Agora::cargaVista ('vistaejemplo', array (
      'titulo' => 'Uso de plantillas con Ágora',
      'texto' => array (
	'He aquí un ejemplo de uso de plantillas con Ágora.&nbsp; Tanto el título como el texto de esta subsección se han definido dinámicamente.&nbsp; De esta forma puede mantener un estilo uniforme en varias páginas de forma simple.',
	'Las plantillas son archivos PHP al uso, por lo que es posible usar bucles dentro de las mismas.&nbsp; Por ejemplo, los párrafos de este texto se han construido de esa forma.&nbsp; También puede usar objetos y funciones PHP, incluso métodos de la clase Agora.',
	'Tenga en cuenta que esto puede suponer un agujero en la seguridad, así que no permita a terceros la definición de plantillas o podría tener graves problemas.'
      )
    ));
    Agora::cargaVista ('vistaejemplo', array (
      'titulo' => 'Más información sobre plantillas',
      'texto' => array (
	'Como puede observar, pueden cargarse varias plantillas o incluso usar la misma plantilla varias veces en la misma página.&nbsp; El sistema es muy potente y le permite gran flexibilidad. <mark>Lea la documentación incluida en el paquete</mark>, así como los comentarios del código fuente, para más información.'
      )
    ));
  }
  catch (\Exception $error)
  {
    echo mensajeError ($error->getMessage ());
  }
 ?>
  </section>

  <section id="modulos">
   <header><h2>Uso de módulos</h2></header>
<?php
  try
  {
  # Cargamos el módulo y obtenemos una referencia al objeto creado (por comodidad).
    $objeto = Agora::cargaModulo ('ModuloEjemplo', 'Ejemplo');
  # Y ahora "usamos" el objeto creado.
    echo $objeto->generaSeccion ();
  }
  catch (\Exception $error)
  {
    echo mensajeError ($error->GetMessage ());
  }
 ?>
  </section>

  <footer>
    <p><a href="http://www.burdjia.com/proyectos/agora" target="_blank">Ágora <?= AG_VERSION ?></a> &copy; Guillermo Martínez J. 2009-2025</p>
  </footer>
 </body>
</html>
